@@ -4,6 +4,12 @@
 ((window) => {
   const core = window.Deno.core;
   const { BadResource } = core;
+  const {
+    PromiseResolve,
+    SymbolAsyncIterator,
+    Uint8Array,
+    TypedArrayPrototypeSubarray,
+  } = window.__bootstrap.primordials;
 
   async function read(
     rid,
@@ -128,14 +134,14 @@
 
     return(value) {
       this.close();
-      return Promise.resolve({ value, done: true });
+      return PromiseResolve({ value, done: true });
     }
 
     close() {
       core.close(this.rid);
     }
 
-    [Symbol.asyncIterator]() {
+    [SymbolAsyncIterator]() {
       return this;
     }
   }
@@ -165,7 +171,7 @@
         this.addr.transport,
         buf,
       );
-      const sub = buf.subarray(0, size);
+      const sub = TypedArrayPrototypeSubarray(buf, 0, size);
       return [sub, remoteAddr];
     }
 
@@ -180,7 +186,7 @@
       core.close(this.rid);
     }
 
-    async *[Symbol.asyncIterator]() {
+    async *[SymbolAsyncIterator]() {
       while (true) {
         try {
           yield await this.receive();
